@@ -60,5 +60,5 @@ class DevicePoolSerializer(TagSerializer, serializers.ModelSerializer):
     class Meta:
         model = DevicePool
         fields = [
-            "id", "label", "devicepool", "tenant", "region", "description", "datetimegroup", "localroutegroup", "tags",
+            "id", "label", "devicepool", "tenant", "region", "description", "datetimegroup", "localroutegroup", "cmgroup", "tags",
         ]
\ No newline at end of file
